@@ -19,14 +19,13 @@ from woodwork.utils import (
     _convert_input_to_set,
     _get_mode,
     _new_dt_including,
+    get_valid_mi_types,
     import_or_none,
     import_or_raise
 )
 
 dd = import_or_none('dask.dataframe')
 ks = import_or_none('databricks.koalas')
-if ks:
-    ks.set_option('compute.ops_on_diff_frames', True)
 
 
 class DataTable(object):
@@ -82,6 +81,8 @@ class DataTable(object):
                          table_metadata, column_metadata, semantic_tags, make_index, column_descriptions)
 
         self._dataframe = dataframe
+        if ks and isinstance(dataframe, ks.DataFrame) and not ks.get_option('compute.ops_on_diff_frames'):
+            ks.set_option('compute.ops_on_diff_frames', True)
 
         self.make_index = make_index or None
         if self.make_index:
@@ -320,6 +321,8 @@ class DataTable(object):
         if self.index is not None and index is None:
             updated_index_col = self.columns[self.index].remove_semantic_tags('index')
             self._update_columns({self.index: updated_index_col})
+            self._dataframe = self._dataframe.reset_index(drop=True)
+
         elif index is not None:
             _update_index(self, index, self.index)
         # Update the underlying index
@@ -373,21 +376,15 @@ class DataTable(object):
         '''Sets the index of a DataTable's underlying dataframe on pandas DataTables.
 
         If the DataTable has an index, will be set to that index.
-        If no index is specified and the DataFrame's index isn't a RangeIndex, will reset the DataFrame's index,
-        meaning that the index will be a pd.RangeIndex starting from zero.
+        If no index is specified, the DataFrame's index will remain the same.
         '''
         needs_update = False
         new_df = self._dataframe
-        if isinstance(self._dataframe, pd.DataFrame):
-            if self.index is not None:
-                needs_update = True
-                new_df = self._dataframe.set_index(self.index, drop=False)
-                # Drop index name to not overlap with the original column
-                new_df.index.name = None
-            # Only reset the index if the index isn't a RangeIndex
-            elif not isinstance(self._dataframe.index, pd.RangeIndex):
-                needs_update = True
-                new_df = self._dataframe.reset_index(drop=True)
+        if isinstance(self._dataframe, pd.DataFrame) and self.index is not None:
+            needs_update = True
+            new_df = self._dataframe.set_index(self.index, drop=False)
+            # Drop index name to not overlap with the original column
+            new_df.index.name = None
 
         self._dataframe = new_df
         return needs_update
@@ -402,6 +399,9 @@ class DataTable(object):
             woodwork.DataColumn: DataColumn including logical type and semantic tags.
         """
         col = self[column_name]
+        if 'index' in col.semantic_tags:
+            self._dataframe = self._dataframe.reset_index(drop=True)
+
         del self.columns[column_name]
         self._dataframe = self._dataframe.drop(column_name, axis=1)
         return col
@@ -422,7 +422,10 @@ class DataTable(object):
         if not_present:
             raise ValueError(f'{not_present} not found in DataTable')
 
-        return self._new_dt_from_cols([col for col in self._dataframe.columns if col not in columns])
+        dt = self._new_dt_from_cols([col for col in self._dataframe.columns if col not in columns])
+        if dt.index is None and self.index is not None:
+            dt._dataframe = dt._dataframe.reset_index(drop=True)
+        return dt
 
     def rename(self, columns):
         """Renames columns in a DataTable
@@ -490,6 +493,9 @@ class DataTable(object):
 
         Args:
             time_index (str): The name of the column to set as the time index.
+
+        Returns:
+            woodwork.DataTable: DataTable with the specified time index column set.
         """
         new_dt = self._new_dt_from_cols(self._dataframe.columns)
         _update_time_index(new_dt, time_index, self.time_index)
@@ -530,6 +536,8 @@ class DataTable(object):
             cols_to_update[col_name] = col
 
         new_dt._update_columns(cols_to_update)
+        if new_dt.index is None and self.index is not None:
+            new_dt._dataframe = new_dt._dataframe.reset_index(drop=True)
         return new_dt
 
     def add_semantic_tags(self, semantic_tags):
@@ -559,7 +567,10 @@ class DataTable(object):
             woodwork.DataTable: DataTable with the specified semantic tags removed
         """
         _check_semantic_tags(self._dataframe, semantic_tags)
-        return self._update_cols_and_get_new_dt('remove_semantic_tags', semantic_tags)
+        dt = self._update_cols_and_get_new_dt('remove_semantic_tags', semantic_tags)
+        if dt.index is None and self.index is not None:
+            dt._dataframe = dt._dataframe.reset_index(drop=True)
+        return dt
 
     def reset_semantic_tags(self, columns=None, retain_index_tags=False):
         """Reset the semantic tags for the specified columns to the default values and
@@ -585,7 +596,10 @@ class DataTable(object):
                               f"dataframe: '{', '.join(cols_not_found)}'")
         if not columns:
             columns = self._dataframe.columns
-        return self._update_cols_and_get_new_dt('reset_semantic_tags', columns, retain_index_tags)
+        dt = self._update_cols_and_get_new_dt('reset_semantic_tags', columns, retain_index_tags)
+        if dt.index is None and self.index is not None:
+            dt._dataframe = dt._dataframe.reset_index(drop=True)
+        return dt
 
     def _update_cols_and_get_new_dt(self, method, new_values, *args):
         """Helper method that can be used for updating columns by calling the column method
@@ -929,7 +943,7 @@ class DataTable(object):
             val_counts[col] = dt_list
         return val_counts
 
-    def _handle_nans_for_mutual_info(self, data):
+    def _replace_nans_for_mutual_info(self, data):
         """
         Remove NaN values in the dataframe so that mutual information can be calculated
 
@@ -937,12 +951,9 @@ class DataTable(object):
             data (pd.DataFrame): dataframe to use for calculating mutual information
 
         Returns:
-            pd.DataFrame: data with fully null columns removed and nans filled in
-                with either mean or mode
+            pd.DataFrame: data with nans replaced with either mean or mode
 
         """
-        # remove fully null columns
-        data = data.loc[:, data.columns[data.notnull().any()]]
 
         # replace or remove null values
         for column_name in data.columns[data.isnull().any()]:
@@ -950,7 +961,7 @@ class DataTable(object):
             series = data[column_name]
             ltype = column._logical_type
 
-            if column._is_numeric():
+            if column._is_numeric() or _get_ltype_class(ltype) == Datetime:
                 mean = series.mean()
                 if isinstance(mean, float) and not _get_ltype_class(ltype) == Double:
                     data[column_name] = series.astype('float')
@@ -1009,15 +1020,9 @@ class DataTable(object):
             Mutual information values are between 0 (no mutual information) and 1
             (perfect dependency).
         """
-        # We only want Numeric, Categorical, and Boolean columns
-        # And we don't want the index column
-        valid_columns = [col_name for col_name, column
-                         in self.columns.items() if (col_name != self.index and
-                                                     (column._is_numeric() or
-                                                      column._is_categorical() or
-                                                      _get_ltype_class(column.logical_type) == Boolean or
-                                                      _get_ltype_class(column.logical_type) == Datetime)
-                                                     )]
+        valid_types = get_valid_mi_types()
+        valid_columns = [col.name for col in self.columns.values() if (
+            col.name != self.index and _get_ltype_class(col.logical_type) in valid_types)]
 
         data = self._dataframe[valid_columns]
         if dd and isinstance(data, dd.DataFrame):
@@ -1029,7 +1034,16 @@ class DataTable(object):
         if nrows is not None and nrows < data.shape[0]:
             data = data.sample(nrows)
 
-        data = self._handle_nans_for_mutual_info(data)
+        # remove fully null columns
+        not_null_cols = data.columns[data.notnull().any()]
+        if set(not_null_cols) != set(valid_columns):
+            data = data.loc[:, not_null_cols]
+        # remove columns that are unique
+        not_unique_cols = [col for col in data.columns if not data[col].is_unique]
+        if set(not_unique_cols) != set(valid_columns):
+            data = data.loc[:, not_unique_cols]
+
+        data = self._replace_nans_for_mutual_info(data)
         data = self._make_categorical_for_mutual_info(data, num_bins)
 
         # calculate mutual info for all pairs of columns
